LemmasEndpoint class
Check if a word exists in the dictionary, or what 'root' form it links to (e.g., swimming > swim). The response tells you the possible lemmas for a given inflected word. This can then be combined with other endpoints to retrieve more information.
The results can be filtered by lexicalCategories and/or grammaticalFeatures.
Filters can be combined.
Combining different filters will build a query using 'AND' operators, while if a filter contains more than one value it will build a query using 'OR' operators. For example, a combination of filters like '?grammaticalFeatures=singular&lexicalCategory=noun,verb' will return entries which match the query ('noun' OR 'verb') AND 'singular'.
- Inheritance
-
- Object
- OdApiEndpoint<
DictionaryEntry> - LemmasEndpoint
Properties
-
deserializer
→ JsonDeserializer<
DictionaryEntry> -
Deserializes
JSONto an object of typeT.no setter - endpoint → OxfordDictionariesEndpoint
-
The OxfordDictionariesEndpoint enumeration of the OdApiEndpoint.
no setteroverride
-
grammaticalFeatures
→ Iterable<
String> ? -
A comma-separated list of grammaticalFeatures ids to match on.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
Returns the headers for the API endpoint request.
final
- host → String
-
The host part of the API endpoint request.
no setterinherited
- language → Language
-
The ISO language code for the language of a term.
final
- lexicalCategory → PartOfSpeech?
-
A comma-separated list of lexical categories ids to match on
final
- name → String
-
Returns the name of the endpoint
no setterinherited
- path → String
-
The path element for the API endpoint uri.
no setter
- porter2stem → String
-
Uses the
Porter2Stemmerto return the stem of term.no setterinherited - protocol → HttpProtocol
-
The protocol of the API endpoint.
no setterinherited
-
queryParameters
→ Map<
String, String> -
The query parameters for the endpoint.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serializer
→ JsonSerializer<
DictionaryEntry> -
Serializes an object of type
TtoJSON.no setterinherited - term → String
-
The term parameter requested from the endpoint.
final
Methods
-
get(
) → Future< DictionaryEntry?> -
Asynchronously returns an object of type
Tfrom the API endpoint.inherited -
getJson(
) → Future< Map< String, dynamic> ?> -
Returns the JSON for the endpoint
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
post(
DictionaryEntry? obj) → Future< DictionaryEntry?> -
Asynchronously posts an
objof typeTto the API endpoint using POST.inherited -
postJson(
JSON? json) → Future< Map< String, dynamic> ?> -
Asynchronously posts a
jsondocument to the API endpoint using POST.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
query(
String term, Map< String, String> apiKeys, {Language language = Language.en_US, Iterable<String> ? grammaticalFeatures, PartOfSpeech? lexicalCategory}) → Future<DictionaryEntry?> -
Queries the LemmasEndpoint for a DictionaryEntry for the
termand optional parameters.